##
##  pgbouncer.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         pgbouncer
Summary:      PostgreSQL Connection Pooling
URL:          https://pgbouncer.github.io/
Vendor:       Scott Emmons
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      MIT
Version:      1.24.1
Release:      20250417

#   list of sources
Source0:      https://pgbouncer.github.io/downloads/files/%{version}/pgbouncer-%{version}.tar.gz
Source1:      pgbouncer.ini
Source2:      rc.pgbouncer

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  openssl, ares
PreReq:       openssl, ares

%description
    PgBouncer is a lightweight connection pooler for the PostgreSQL
    RDBMS. It supports session pooling, transaction pooling and
    statement pooling.

%track
    prog pgbouncer = {
        version   = %{version}
        url       = https://pgbouncer.github.io/downloads/
        regex     = pgbouncer-(__VER__)\.tar\.gz
    }

%prep
    %setup -q

%build
    #   configure program
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O} -pthread" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags} -pthread" \
    ./configure \
        --prefix=%{l_prefix} \
        --with-cares=%{l_prefix} \
        --with-openssl=%{l_prefix} \
        --with-root-ca-file=%{l_prefix}/etc/x509/example-ca.crt.pem

    #   build program
    %{l_make} %{l_mflags -O}

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/pgbouncer \
        $RPM_BUILD_ROOT%{l_prefix}/var/pgbouncer/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/pgbouncer/run/pgbouncer.socket \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man5

    #   install program
    %{l_shtool} install -c -s -m 755 \
        pgbouncer $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   install manual pages
    %{l_shtool} install -c -m 644 \
        doc/pgbouncer.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    %{l_shtool} install -c -m 644 \
        doc/pgbouncer.5 $RPM_BUILD_ROOT%{l_prefix}/man/man5/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.pgbouncer} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE pgbouncer.ini} $RPM_BUILD_ROOT%{l_prefix}/etc/pgbouncer/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/pgbouncer/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/pgbouncer/*'

%files -f files

%clean

%post
    if [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} pgbouncer status 2>/dev/null`
        [ ".$pgbouncer_active" = .yes ] && %{l_rc} pgbouncer restart
    fi
    exit 0

%preun
    #   before erase, stop service and remove log files
    if [ $1 -eq 0 ]; then
        %{l_rc} pgbouncer stop 2>/dev/null
        rm -f $RPM_INSTALL_PREFIX/var/pgbouncer/log/* >/dev/null 2>&1 || true
        rm -f $RPM_INSTALL_PREFIX/var/pgbouncer/run/* >/dev/null 2>&1 || true
    fi
    exit 0

